# grill-names
Name objects for digital content creation

[![Build Status](https://travis-ci.org/thegrill/grill-names.svg?branch=master)](https://travis-ci.org/thegrill/grill-names)
[![Coverage Status](https://coveralls.io/repos/github/thegrill/grill-names/badge.svg)](https://coveralls.io/github/thegrill/grill-names)
[![PyPI version](https://badge.fury.io/py/grill-names.svg)](https://badge.fury.io/py/grill-names)
[![PyPI](https://img.shields.io/pypi/pyversions/grill-names.svg)](https://pypi.python.org/pypi/grill-names)

[Read the Docs](http://grill-names.readthedocs.io)
